@@ -3,13 +3,13 @@ from typing import Iterable, List, Tuple, Union
 
 import numpy as np
 
-from physrisk.kernel.assets import Asset
-from physrisk.kernel.curve import ExceedanceCurve
-from physrisk.kernel.hazard_event_distrib import HazardEventDistrib
-from physrisk.kernel.hazard_model import EventDataRequest, EventDataResponse
-from physrisk.kernel.impact_curve import ImpactCurve
-from physrisk.kernel.impact_distrib import ImpactDistrib
-from physrisk.kernel.vulnerability_distrib import VulnerabilityDistrib
+from .assets import Asset
+from .curve import ExceedanceCurve
+from .hazard_event_distrib import HazardEventDistrib
+from .hazard_model import EventDataRequest, EventDataResponse
+from .impact_curve import ImpactCurve
+from .impact_distrib import ImpactDistrib
+from .vulnerability_distrib import VulnerabilityDistrib
 
 PLUGINS = dict()
 
